From 9475aa917dabe2f53b69d377d686602f6696e5e8 Mon Sep 17 00:00:00 2001
From: Neil Conway <neilc@samurai.com>
Date: Thu, 26 Apr 2007 18:10:28 +0000
Subject: [PATCH] Minor enhancement to psql tab completion. If we see "CREATE
 TEMPORARY", we can complete "TABLE". The previous coding only looked for
 "CREATE TEMP".

Note that I didn't add TEMPORARY to the list of suggested completions
after we've seen "CREATE", since TEMP is equivalent and more concise. But
if the user has already manually typed TEMPORARY, we may as well
complete TABLE for them.
---
 src/bin/psql/tab-complete.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/src/bin/psql/tab-complete.c b/src/bin/psql/tab-complete.c
index 2ec534cba49..876c3a698c2 100644
--- a/src/bin/psql/tab-complete.c
+++ b/src/bin/psql/tab-complete.c
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2000-2007, PostgreSQL Global Development Group
  *
- * $PostgreSQL: pgsql/src/bin/psql/tab-complete.c,v 1.162 2007/04/26 16:13:13 neilc Exp $
+ * $PostgreSQL: pgsql/src/bin/psql/tab-complete.c,v 1.163 2007/04/26 18:10:28 neilc Exp $
  */
 
 /*----------------------------------------------------------------------
@@ -1107,9 +1107,10 @@ psql_completion(char *text, int start, int end)
 		COMPLETE_WITH_SCHEMA_QUERY(Query_for_list_of_tables, NULL);
 
 /* CREATE TABLE */
 	/* Complete CREATE TEMP with "TABLE" */
 	else if (pg_strcasecmp(prev2_wd, "CREATE") == 0 &&
-			 pg_strcasecmp(prev_wd, "TEMP") == 0)
+			 (pg_strcasecmp(prev_wd, "TEMP") == 0 ||
+			  pg_strcasecmp(prev_wd, "TEMPORARY") == 0))
 		COMPLETE_WITH_CONST("TABLE");
 
 /* CREATE TABLESPACE */
@@ -1107,9 +1107,10 @@ psql_completion(char *text, int start, int end)
 
 /* CREATE TABLE */
-	/* Complete CREATE TEMP with "TABLE" */
+	/* Complete CREATE TEMP/TEMPORARY with "TABLE" */
 	else if (pg_strcasecmp(prev2_wd, "CREATE") == 0 &&
-- 
GitLab